Update references to master branch

Change-Id: I1bfd1b655af6cdfbd64452b1e594a276425095fe
Bug: skia:11987
Docs-Preview: https://skia.org/?cl=410790
Reviewed-on: https://skia-review.googlesource.com/c/skia/+/410790
Reviewed-by: Eric Boren <borenet@google.com>
Commit-Queue: Ravi Mistry <rmistry@google.com>
diff --git a/bin/try.py b/bin/try.py
index cc2e84c..fc9c42b 100755
--- a/bin/try.py
+++ b/bin/try.py
@@ -60,7 +60,7 @@
     with utils.chdir(dirname):
       subprocess.check_call([utils.GIT, 'remote', 'update'])
       jobs = json.loads(subprocess.check_output([
-          utils.GIT, 'show', 'master:%s' % JOBS_JSON]))
+          utils.GIT, 'show', 'main:%s' % JOBS_JSON]))
       return (BUCKET_SKIA_INTERNAL, jobs)
 
 
diff --git a/experimental/documentation/gerrit.md b/experimental/documentation/gerrit.md
index febfbfa..effd1e4 100644
--- a/experimental/documentation/gerrit.md
+++ b/experimental/documentation/gerrit.md
@@ -36,7 +36,7 @@
 
     You may want to set a tracking branch at this time with:
 
-        git checkout -b TOPIC -t origin/master
+        git checkout -b TOPIC -t origin/main
 
 2.  Make a commit.
 
@@ -54,11 +54,11 @@
 
 4.  Push to Gerrit
 
-        git push origin @:refs/for/master
+        git push origin @:refs/for/main
 
     `@` is shorthand for `HEAD`, introduced in git v1.8.5.
 
-    If you want to target a branch other than `master`, that can be specified
+    If you want to target a branch other than `main`, that can be specified
     here, too.  For example:
 
         git push origin @:refs/for/chrome/m57
@@ -86,12 +86,12 @@
 
 3.  Push to Gerrit.
 
-        git push origin @:refs/for/master
+        git push origin @:refs/for/main
 
     If you want to set a comment message for this patch set, do this instead:
 
         M=$(experimental/tools/gerrit_percent_encode 'This is the patch set comment message!')
-        git push origin @:refs/for/master%m=$M
+        git push origin @:refs/for/main%m=$M
 
     The title of this patch set will be "This is the patch set comment message!".
 
@@ -100,7 +100,7 @@
 -------------------------------------------------------
 
     M=$(experimental/tools/gerrit_percent_encode 'This is the patch set comment message!')
-    git push origin @:refs/for/master%l=Commit-Queue+1,m=$M
+    git push origin @:refs/for/main%l=Commit-Queue+1,m=$M
 
 
 Using `git cl try`
@@ -118,7 +118,7 @@
 
 You may want to make git aliases for common tasks:
 
-    git config alias.gerrit-push 'push origin @:refs/for/master'
+    git config alias.gerrit-push 'push origin @:refs/for/main'
 
 The following alias amends the head without editing the commit message:
 
@@ -141,7 +141,7 @@
 
     gerrit_push_with_message() {
         local REMOTE='origin'
-        local REMOTE_BRANCH='master'
+        local REMOTE_BRANCH='main'
         local MESSAGE="$(echo $*|sed 's/[^A-Za-z0-9]/_/g')"
         git push "$REMOTE" "@:refs/for/${REMOTE_BRANCH}%m=${MESSAGE}"
     }
@@ -150,7 +150,7 @@
 
     git config alias.squash-branch '!M="$(git log --format=%B ^@{u} @)";git reset --soft $(git merge-base @ @{u});git commit -m "$M" -e'
 
-    git config alias.gerrit-push-message '!f(){ git push origin @:refs/for/master%m=$(echo $*|sed "s/[^A-Za-z0-9]/_/g");};f'
+    git config alias.gerrit-push-message '!f(){ git push origin @:refs/for/main%m=$(echo $*|sed "s/[^A-Za-z0-9]/_/g");};f'
 
 If your branch's upstream branch (set with `git branch --set-upstream-to=...`)
 is set, you can use that to automatically push to that branch:
diff --git a/infra/README.md b/infra/README.md
index 2447756..7e8df4e 100644
--- a/infra/README.md
+++ b/infra/README.md
@@ -1,5 +1,5 @@
 This directory contains infra-specific files. The branch-config/ directory
-contains configs that are specific to the master branch (e.g. config for the CQ
-committing to the master branch), while project-config/ directory contains
+contains configs that are specific to the main branch (e.g. config for the CQ
+committing to the main branch), while project-config/ directory contains
 project-wide configuration (e.g. list of buckets for cr-buildbucket service and
 list of refs known to the infra services).
diff --git a/infra/bots/README.md b/infra/bots/README.md
index 823962d..e183b50 100644
--- a/infra/bots/README.md
+++ b/infra/bots/README.md
@@ -19,7 +19,7 @@
 The tasks.json file in this directory is the list of tasks and jobs for
 the repo. Note that tasks.json is NEVER edited by hand but generated via
 gen_task.go and the input files enumerated below. The
-[Task Scheduler](https://skia.googlesource.com/buildbot/+/master/task_scheduler/README.md)
+[Task Scheduler](https://skia.googlesource.com/buildbot/+/main/task_scheduler/README.md)
 reads the tasks.json file at each commit to determine which jobs to run. For
 convenience, gen_tasks.go is provided to generate tasks.json and also to test it
 for correct syntax and detecting cycles and orphaned tasks. Always edit
@@ -69,7 +69,7 @@
 
 These files determine which parts of the repository are transferred to the bot
 when a Swarming task is triggered. The
-[Isolate tool](https://github.com/luci/luci-py/tree/master/appengine/isolate/doc)
+[Isolate tool](https://github.com/luci/luci-py/tree/main/appengine/isolate/doc)
 hashes each file and will upload any new/changed files. Bots maintain a cache so
 that they can efficiently download only the files they don't have.
 
diff --git a/infra/bots/recipe_modules/checkout/api.py b/infra/bots/recipe_modules/checkout/api.py
index fb554ee..f6e771c 100644
--- a/infra/bots/recipe_modules/checkout/api.py
+++ b/infra/bots/recipe_modules/checkout/api.py
@@ -98,7 +98,7 @@
     main.name = main_name
     main.managed = False
     main.url = main_repo
-    main.revision = self.m.properties.get('revision') or 'origin/master'
+    main.revision = self.m.properties.get('revision') or 'origin/main'
     m = gclient_cfg.got_revision_mapping
     m[main_name] = 'got_revision'
     patch_root = main_name
diff --git a/infra/bots/utils.py b/infra/bots/utils.py
index a732b7e..62d828a 100755
--- a/infra/bots/utils.py
+++ b/infra/bots/utils.py
@@ -100,11 +100,11 @@
       self._orig_branch = subprocess.check_output([
           GIT, 'rev-parse', 'HEAD']).rstrip()
 
-    # Check out a new branch, based at updated origin/master.
+    # Check out a new branch, based at updated origin/main.
     subprocess.check_call([GIT, 'fetch', 'origin'])
     self._branch = '_tmp_%s' % uuid.uuid4()
     subprocess.check_call([GIT, 'checkout', '-b', self._branch,
-                           '-t', 'origin/master'])
+                           '-t', 'origin/main'])
     return self
 
   def __exit__(self, exc_type, _value, _traceback):
diff --git a/site/docs/dev/contrib/_index.md b/site/docs/dev/contrib/_index.md
index ea99972..14b14cc 100644
--- a/site/docs/dev/contrib/_index.md
+++ b/site/docs/dev/contrib/_index.md
@@ -55,7 +55,7 @@
 
 - If it is your first time submitting code or you have not previously done so,
   add your (or your organization's) name and contact info to the
-  [AUTHORS file](https://skia.googlesource.com/skia/+/master/AUTHORS) as a part
+  [AUTHORS file](https://skia.googlesource.com/skia/+/main/AUTHORS) as a part
   of your CL.
 
 REVIEWERS: Before you LGTM a change, verify that the contributor is listed in
diff --git a/site/docs/dev/contrib/revert.md b/site/docs/dev/contrib/revert.md
index b8e7a2e..6c07414 100644
--- a/site/docs/dev/contrib/revert.md
+++ b/site/docs/dev/contrib/revert.md
@@ -16,15 +16,15 @@
 
 Update the local repository
 
-    git fetch origin master
+    git fetch origin main
 
-Create a local branch with origin/master as its start point.
+Create a local branch with origin/main as its start point.
 
-    git checkout -b revert$RANDOM origin/master
+    git checkout -b revert$RANDOM origin/main
 
 Find the SHA1 of the commit you want to revert
 
-    git log origin/master
+    git log origin/main
 
 Create a revert commit.
 
@@ -34,7 +34,7 @@
 
     git cl upload
 
-Land the revert in origin/master.
+Land the revert in origin/main.
 
     git cl land
 
diff --git a/site/docs/dev/contrib/submit.md b/site/docs/dev/contrib/submit.md
index d9ebcf0..bebb946 100644
--- a/site/docs/dev/contrib/submit.md
+++ b/site/docs/dev/contrib/submit.md
@@ -17,7 +17,7 @@
 <!--?prettify lang=sh?-->
 
     git config branch.autosetuprebase always
-    git checkout -b my_feature origin/master
+    git checkout -b my_feature origin/main
 
 After making your changes, create a commit
 
@@ -169,7 +169,7 @@
 Once your commit has gone in, you should delete the branch containing your
 change:
 
-    git checkout -q origin/master
+    git checkout -q origin/main
     git branch -D my_feature
 
 ## Final Testing
diff --git a/site/docs/dev/flutter/_index.md b/site/docs/dev/flutter/_index.md
index 40c44b4..947e94b 100644
--- a/site/docs/dev/flutter/_index.md
+++ b/site/docs/dev/flutter/_index.md
@@ -29,7 +29,7 @@
 - Deprecate the old code path so that it must be enabled with a flag such as
   'SK_SUPPORT_LEGACY_XXX'.
 - Add that same flag to
-  [flutter_defines.gni](https://skia.googlesource.com/skia/+/master/gn/flutter_defines.gni)
+  [flutter_defines.gni](https://skia.googlesource.com/skia/+/main/gn/flutter_defines.gni)
   in Skia.
   - Both Flutter and Fuchsia build Skia with a GN argument that enables all the
     defines listed in that file.
diff --git a/site/docs/dev/testing/automated_testing.md b/site/docs/dev/testing/automated_testing.md
index 48f687c..a01c8f5 100644
--- a/site/docs/dev/testing/automated_testing.md
+++ b/site/docs/dev/testing/automated_testing.md
@@ -34,7 +34,7 @@
 	$ go run infra/bots/gen_tasks.go
 
 It is necessary to run `gen_tasks.go` every time it is changed or every time an
-[asset](https://skia.googlesource.com/skia/+/master/infra/bots/assets/README.md)
+[asset](https://skia.googlesource.com/skia/+/main/infra/bots/assets/README.md)
 has changed. There is also a test mode which simply verifies that the `tasks.json`
 file is up to date:
 
@@ -127,13 +127,13 @@
 
 [new bot request]:
     https://bugs.chromium.org/p/skia/issues/entry?template=New+Bot+Request
-[jobs json]: https://skia.googlesource.com/skia/+/master/infra/bots/jobs.json
+[jobs json]: https://skia.googlesource.com/skia/+/main/infra/bots/jobs.json
 [build recipe module]:
     https://skia.googlesource.com/skia/+/refs/heads/master/infra/bots/recipe_modules/build/
 [test py]:
-    https://skia.googlesource.com/skia/+/master/infra/bots/recipes/test.py
+    https://skia.googlesource.com/skia/+/main/infra/bots/recipes/test.py
 [perf py]:
-    https://skia.googlesource.com/skia/+/master/infra/bots/recipes/perf.py
+    https://skia.googlesource.com/skia/+/main/infra/bots/recipes/perf.py
 
 
 Detail on Skia Tasks
@@ -179,15 +179,15 @@
 mtklein.
 
 [gen_tasks]:
-	https://skia.googlesource.com/skia/+/master/infra/bots/gen_tasks.go
+	https://skia.googlesource.com/skia/+/main/infra/bots/gen_tasks.go
 [cfg json]:
-	https://skia.googlesource.com/skia/+/master/infra/bots/cfg.json
+	https://skia.googlesource.com/skia/+/main/infra/bots/cfg.json
 [builder_name_schema]:
-	https://skia.googlesource.com/skia/+/master/infra/bots/recipe_modules/builder_name_schema/builder_name_schema.json
+	https://skia.googlesource.com/skia/+/main/infra/bots/recipe_modules/builder_name_schema/builder_name_schema.json
 [recipes README]:
-    https://skia.googlesource.com/skia/+/master/infra/bots/recipes/README.md
+    https://skia.googlesource.com/skia/+/main/infra/bots/recipes/README.md
 [recipe_modules README]:
-    https://skia.googlesource.com/skia/+/master/infra/bots/recipe_modules/README.md
+    https://skia.googlesource.com/skia/+/main/infra/bots/recipe_modules/README.md
 [isolate user guide]:
     https://chromium.googlesource.com/infra/luci/luci-py/+/master/appengine/isolate/doc/client/Isolate-User-Guide.md
 
diff --git a/site/docs/dev/testing/skqp.md b/site/docs/dev/testing/skqp.md
index 0a2db87..c1dae85 100644
--- a/site/docs/dev/testing/skqp.md
+++ b/site/docs/dev/testing/skqp.md
@@ -52,5 +52,5 @@
 * * *
 
 For more information about building your own APK, refer to
-https://skia.googlesource.com/skia/+/master/tools/skqp/README.md
+https://skia.googlesource.com/skia/+/main/tools/skqp/README.md
 
diff --git a/site/docs/dev/tools/sk.md b/site/docs/dev/tools/sk.md
index ca6354d..a513c14 100644
--- a/site/docs/dev/tools/sk.md
+++ b/site/docs/dev/tools/sk.md
@@ -17,7 +17,7 @@
 Used for managing versioned non-code assets used by Skia developers and in CI.
 These are stored in [CIPD](https://chrome-infra-packages.appspot.com/p/skia/bots)
 and their versions are pinned under
-[//infra/bots/assets](https://skia.googlesource.com/skia/+/master/infra/bots/assets)
+[//infra/bots/assets](https://skia.googlesource.com/skia/+/main/infra/bots/assets)
 in Skia.
 
 * add - Add an entry for a new asset. This does not create an initial version.
@@ -63,5 +63,5 @@
 New versions of `sk` are automatically built and uploaded to
 [CIPD](https://chrome-infra-packages.appspot.com/p/skia/tools/sk) as part of
 Skia Infra's CI/CD pipeline.  The version used by Skia is pinned in
-[DEPS](https://skia.googlesource.com/skia/+/master/DEPS) and updated by an
+[DEPS](https://skia.googlesource.com/skia/+/main/DEPS) and updated by an
 [autoroller](https://autoroll.skia.org/r/sk-tool-skia).
diff --git a/site/docs/user/build.md b/site/docs/user/build.md
index 73fb57e..457ceb3 100644
--- a/site/docs/user/build.md
+++ b/site/docs/user/build.md
@@ -184,10 +184,10 @@
 
 If you don't have authorization to use those assets, then see the README.md
 files for
-[armhf_sysroot](https://skia.googlesource.com/skia/+/master/infra/bots/assets/armhf_sysroot/README.md),
-[chromebook_arm_gles](https://skia.googlesource.com/skia/+/master/infra/bots/assets/chromebook_arm_gles/README.md),
+[armhf_sysroot](https://skia.googlesource.com/skia/+/main/infra/bots/assets/armhf_sysroot/README.md),
+[chromebook_arm_gles](https://skia.googlesource.com/skia/+/main/infra/bots/assets/chromebook_arm_gles/README.md),
 and
-[chromebook_x86_64_gles](https://skia.googlesource.com/skia/+/master/infra/bots/assets/chromebook_x86_64_gles/README.md)
+[chromebook_x86_64_gles](https://skia.googlesource.com/skia/+/main/infra/bots/assets/chromebook_x86_64_gles/README.md)
 for instructions on creating those assets.
 
 Once those files are in place, generate the GN args that resemble the following:
diff --git a/site/docs/user/modules/skottie.md b/site/docs/user/modules/skottie.md
index fc01995..2a62f69 100644
--- a/site/docs/user/modules/skottie.md
+++ b/site/docs/user/modules/skottie.md
@@ -61,7 +61,7 @@
 ## The code
 
 Skia's animation code entry point can be found here on
-[Googlesource](https://skia.googlesource.com/skia/+/master/modules/skottie/include/Skottie.h)
+[Googlesource](https://skia.googlesource.com/skia/+/main/modules/skottie/include/Skottie.h)
 and
 [GitHub](https://github.com/google/skia/blob/master/modules/skottie/include/Skottie.h).
 The code is part of Skia's library but can also be made available as a separate
diff --git a/site/docs/user/release/schedule.md b/site/docs/user/release/schedule.md
index 4dfb9d1..2889289 100644
--- a/site/docs/user/release/schedule.md
+++ b/site/docs/user/release/schedule.md
@@ -32,5 +32,5 @@
 Skia is maintaining 82 for our customers. Future dates are subject to change.
 
 The current milestone is included in the headers in
-[SkMilestone.h](https://skia.googlesource.com/skia/+/master/include/core/SkMilestone.h).
+[SkMilestone.h](https://skia.googlesource.com/skia/+/main/include/core/SkMilestone.h).
 
diff --git a/site/docs/user/tips.md b/site/docs/user/tips.md
index 2c92f80..c980514 100644
--- a/site/docs/user/tips.md
+++ b/site/docs/user/tips.md
@@ -72,7 +72,7 @@
     There are sets of bottleneck routines inside the blits of Skia that can be
     replace on a platform in order to take advantage of specific CPU features.
     One such example is the NEON SIMD instructions on ARM v7 devices. See
-    [src/opts/](https://skia.googlesource.com/skia/+/master/src/opts/)
+    [src/opts/](https://skia.googlesource.com/skia/+/main/src/opts/)
 
 ---
 
diff --git a/tools/calmbench/calmbench.py b/tools/calmbench/calmbench.py
index 798ab4e..e83170b 100755
--- a/tools/calmbench/calmbench.py
+++ b/tools/calmbench/calmbench.py
@@ -20,7 +20,7 @@
 \033[36m
     python {0} TEST_GIT_BRANCH
 \033[0m
-to see if TEST_GIT_BRANCH has performance regressions against master in 8888.
+to see if TEST_GIT_BRANCH has performance regressions against main in 8888.
 
 To compare a specific config with svg and skp resources included, add --config
 and --extraarg option. For exampe,
@@ -44,7 +44,7 @@
 
   parser = ArgumentParser(
     description='Noiselessly (hence calm) becnhmark a git branch against ' +
-                'another baseline branch (e.g., master) using multiple ' +
+                'another baseline branch (e.g., main) using multiple ' +
                 ' nanobench runs.'
   )
 
@@ -87,7 +87,7 @@
     ['--ninjadir',  str, 'out/Release', 'default: %(default)s'],
     ['--writedir',  str, '/var/tmp', 'default: %(default)s'],
     ['--extraarg',  str, '', extraarg_help],
-    ['--baseline',  str, 'master', baseline_help],
+    ['--baseline',  str, 'main', baseline_help],
     ['--basearg',   str, '', basearg_help],
     ['--reps',      int, 2, reps_help],
     ['--threads',   int, default_threads, threads_help],
diff --git a/tools/milestone.py b/tools/milestone.py
index 2577277..9a63f9d 100755
--- a/tools/milestone.py
+++ b/tools/milestone.py
@@ -12,7 +12,7 @@
 usage = '''
 usage:
   git fetch
-  git checkout -b change_milestone origin/master
+  git checkout -b change_milestone origin/main
   python %s MILESTONE_NUMBER
   git add %s
   git commit -m "Update Skia milestone."
diff --git a/tools/retrieve_from_googlesource.py b/tools/retrieve_from_googlesource.py
index 2f78ce0..45f8ac2 100755
--- a/tools/retrieve_from_googlesource.py
+++ b/tools/retrieve_from_googlesource.py
@@ -25,7 +25,7 @@
   Return:
       string; the contents of the given file.
   """
-  base64_url = '/'.join((repo_url, '+', 'master', filepath)) + '?format=TEXT'
+  base64_url = '/'.join((repo_url, '+', 'main', filepath)) + '?format=TEXT'
   with closing(urllib2.urlopen(base64_url)) as f:
     return base64.b64decode(f.read())
 
diff --git a/tools/skqp/README_GENERATING_MODELS.md b/tools/skqp/README_GENERATING_MODELS.md
index b852564..4351909 100644
--- a/tools/skqp/README_GENERATING_MODELS.md
+++ b/tools/skqp/README_GENERATING_MODELS.md
@@ -1,19 +1,19 @@
 How SkQP Generates Render Test Models
 =====================================
 
-We will, at regular intervals, generate new models from the [master branch of
+We will, at regular intervals, generate new models from the [main branch of
 Skia][1].  Here is how that process works:
 
 0.  Choose a commit to make the branch from
 
-        COMMIT=origin/master
+        COMMIT=origin/main
 
     Or use the script to find the best one:
 
         cd SKIA_SOURCE_DIRECTORY
         git fetch origin
         COMMIT=$(python tools/skqp/find_commit_with_best_gold_results.py \
-                 origin/master ^origin/skqp/dev)
+                 origin/main ^origin/skqp/dev)
 
 1.  Get the positively triaged results from Gold and generate models:
 
@@ -80,5 +80,5 @@
 Finally, a list of the current gpu unit tests is created and stored in
 `skqp/unittests.txt`.
 
-[1]: https://skia.googlesource.com/skia/+log/master "Skia Master Branch"
-[2]: https://gold.skia.org/search                   "Skia Gold Search"
+[1]: https://skia.googlesource.com/skia/+log/main "Skia Main Branch"
+[2]: https://gold.skia.org/search                 "Skia Gold Search"
diff --git a/tools/skqp/find_commit_with_best_gold_results.py b/tools/skqp/find_commit_with_best_gold_results.py
index d825b1a..be24491 100755
--- a/tools/skqp/find_commit_with_best_gold_results.py
+++ b/tools/skqp/find_commit_with_best_gold_results.py
@@ -121,7 +121,7 @@
 
 
 usage = '''Example usage:
-    python %s origin/master ^origin/skqp/dev < /dev/null > LOG 2>&1 & disown
+    python %s origin/main ^origin/skqp/dev < /dev/null > LOG 2>&1 & disown
 '''
 
 if __name__ == '__main__':
diff --git a/tools/skqp/make_apk_list.py b/tools/skqp/make_apk_list.py
index 32c9847..00968f4 100755
--- a/tools/skqp/make_apk_list.py
+++ b/tools/skqp/make_apk_list.py
@@ -126,8 +126,8 @@
     path = os.path.join(d, 'apklist.html')
     with open(path, 'w') as o:
         o.write(HEADER)
-        table(o, origin,    'skqp/dev',     [(origin, 'master'), '3e34285f2a0'])
-        table(o, origin,    'skqp/release', [(origin, 'master'), '09ab171c5c0'])
+        table(o, origin,    'skqp/dev',     [(origin, 'main'), '3e34285f2a0'])
+        table(o, origin,    'skqp/release', [(origin, 'main'), '09ab171c5c0'])
         table(o, aosp_skqp, 'pie-cts-dev',  ['f084c17322'])
         o.write(FOOTER)
     print(path)
diff --git a/infra/bots/git_utils.py b/infra/bots/git_utils.py
index 893c9cd..d45f9b3 100755
--- a/infra/bots/git_utils.py
+++ b/infra/bots/git_utils.py
@@ -44,7 +44,7 @@
   """Class to manage git branches.
 
   This class allows one to create a new branch in a repository to make changes,
   then it commits the changes, switches to master branch, and deletes the
   created temporary branch upon exit.
   """
   def __init__(self, branch_name, commit_msg, upload=True, commit_queue=False,
@@ -59,11 +59,11 @@
 
   def __enter__(self):
     subprocess.check_call(['git', 'reset', '--hard', 'HEAD'])
-    subprocess.check_call(['git', 'checkout', 'master'])
+    subprocess.check_call(['git', 'checkout', 'main'])
     if self._branch_name in subprocess.check_output(['git', 'branch']).split():
       subprocess.check_call(['git', 'branch', '-D', self._branch_name])
     subprocess.check_call(['git', 'checkout', '-b', self._branch_name,
-                           '-t', 'origin/master'])
+                           '-t', 'origin/main'])
     return self
 
   def commit_and_upload(self, use_commit_queue=False):
@@ -92,7 +92,7 @@
         if exc_type is None:
           self.commit_and_upload(use_commit_queue=self._commit_queue)
       finally:
-        subprocess.check_call(['git', 'checkout', 'master'])
+        subprocess.check_call(['git', 'checkout', 'main'])
         if self._delete_when_finished:
           subprocess.check_call(['git', 'branch', '-D', self._branch_name])
 
@@ -155,6 +155,6 @@
       subprocess.check_call([
           'git', 'remote', 'set-url', 'origin', self._repository])
       subprocess.check_call(['git', 'remote', 'update'])
-      subprocess.check_call(['git', 'checkout', 'master'])
-      subprocess.check_call(['git', 'reset', '--hard', 'origin/master'])
+      subprocess.check_call(['git', 'checkout', 'main'])
+      subprocess.check_call(['git', 'reset', '--hard', 'origin/main'])
     return self
@@ -44,7 +44,7 @@
 
   This class allows one to create a new branch in a repository to make changes,
-  then it commits the changes, switches to master branch, and deletes the
+  then it commits the changes, switches to main branch, and deletes the
   created temporary branch upon exit.
   """